package
Version:
v0.2.9
Opens a new window with list of versions in this module.
Published: Mar 14, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
IsNewer reports whether remote is a different (presumably newer) version
than local. For "dev" builds, always returns true.
type ReleaseInfo struct {
TagName string `json:"tag_name"`
HTMLURL string `json:"html_url"`
}
ReleaseInfo holds metadata about a GitHub release.
Latest queries the GitHub releases API for the latest release.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.